Yamaha Remote Control Protocol (Rust)
Remote control of Yamaha mixing consoles using IP networking.
Disclaimer
This library’s API is nowhere near the “final” API. Development will follow Semantic Versioning, but expect many changes.
Also,
yamaha-rcpis mainly tested against the Yamaha TF Series of consoles, specifically the TF1. Fully tested compatibility of the Rivage PM, DM7, DM3, CL, and QL lines is the final goal of this library, but I do not have access to any of these consoles to be able to test against. If you do happen to have access and are willing to help out development, please get in touch.
Example
use yamaha_rcp::{TFMixer, Error};
#[tokio::main]
async fn main() -> Result<(), Error> {
let mixer = TFMixer::new("192.168.0.128:49280").await?;
// Set channel 1 to -10.00 dB
mixer.set_fader_level(0, -10_00).await?;
Ok(())
}Extra Documentation
The following is a personal collection of documentation on Yamaha’s mixer control protocol since they don’t provide any decent version of their own: github.com/BrenekH/yamaha-rcp-docs
Structs
- TFMixer
- Main entry point to access a TF series mixer
Enums
- Error
- Enumeration of errors that originate from
yamaha-rcp-rs - Label
Color - All possible colors that the TF1 console can use for a channel
- Scene
List - Possible scene lists that scenes may be stored in